==> oct8ne-v.1.2.9.zip: oct8ne/translations/it.php <==
<?php

global $_MODULE;
$_MODULE = [];
$_MODULE['<{oct8ne}prestashop>oct8ne_bc741b828f1fc35a6f10c870d6056343'] = 'Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_8ff7439dd2ee3184597be0c738ad566a'] = 'Connettore del modulo Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_a9390206b02d5d06ee405aa6b4d7b232'] = 'Tutti i dati verranno cancellati. Desidera continuare?';
$_MODULE['<{oct8ne}prestashop>oct8ne_004b04925fa8a42d0d28c3862c6947bd'] = 'Identificazione errata. Per favore, verifica le tue credenziali di accesso.';
$_MODULE['<{oct8ne}prestashop>oct8ne_5f2faa4c7bc8b0d9862218f744a1aee3'] = 'Configurazione di Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{oct8ne}prestashop>oct8ne_3d236caa22b35b852d3d9f402ecd361d'] = 'La tua email...';
$_MODULE['<{oct8ne}prestashop>oct8ne_dc647eb65e6711e155375218212b3964'] = 'Password';
$_MODULE['<{oct8ne}prestashop>oct8ne_45e37dc42e288221084fc298cd93c8bb'] = 'La tua password...';
$_MODULE['<{oct8ne}prestashop>oct8ne_98045f7a4e566c2167bac30218c338ac'] = 'Dovrai compilare i campi inserendo i dati dell\'account del pannello di amministrazione di Oct8ne. Se ancora non hai un account di Oct8ne puoi crearlo';
$_MODULE['<{oct8ne}prestashop>oct8ne_6c92285fa6d3e827b198d120ea3ac674'] = 'qui';
$_MODULE['<{oct8ne}prestashop>oct8ne_99dea78007133396a7b8ed70578ac6ae'] = 'Iniziare sessione';
$_MODULE['<{oct8ne}prestashop>oct8ne_87e9c089875dbf587734df396ce7423a'] = 'Base di Prestashop';
$_MODULE['<{oct8ne}prestashop>oct8ne_afaa5ee5fcca30cc8ab8b7b8096d76b8'] = 'Doofinder';
$_MODULE['<{oct8ne}prestashop>oct8ne_ede9e64250ae298e24874dfe3c23c567'] = 'Motore di ricerca di Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_14e69b495b4ad97a1c4a468d99169b21'] = 'Motore';
$_MODULE['<{oct8ne}prestashop>oct8ne_daa6b483e9f6ca081ec7e0b4a352f9e9'] = 'Salvare';
$_MODULE['<{oct8ne}prestashop>oct8ne_d2cb1b13319e5118823778f3e4505f41'] = 'Informazione di Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_8d1bd3e5756e3454644c531701ff73e0'] = 'Usuario Attivo';
$_MODULE['<{oct8ne}prestashop>oct8ne_0323de4f66a1700e2173e9bcdce02715'] = 'Chiudere sessione';
$_MODULE['<{oct8ne}prestashop>oct8ne_3168ca6855e90fdc6ef9a9022b747df3'] = 'Opzioni';
$_MODULE['<{oct8ne}prestashop>oct8ne_031cf59f5628f2828e2433d82aa26c7a'] = 'Puoi scegliere dove caricare gli script di Oct8ne: Nel footer o nel header della pagina';
$_MODULE['<{oct8ne}prestashop>oct8ne_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posizione';
$_MODULE['<{oct8ne}prestashop>oct8ne_1c8d7e5020585439fe9972e6288b3687'] = 'Tipo di Immagini';
$_MODULE['<{oct8ne}prestashop>oct8ne_a743c9120ecd8b14ccf16ed8d12a68d9'] = 'Tipo 1 inserisce l\'id del prodotto davanti all\'id dell\'immagine. Utile in casi specifici. Attenzione, modifica questa opzione solo se necessario';
$_MODULE['<{oct8ne}prestashop>oct8ne_c9cc8cce247e49bae79f15173ce97354'] = 'Salvare';
$_MODULE['<{oct8ne}prestashop>customerconfig_b0d07cb35250063972daeb65e388ee3d'] = 'Configurazione basica - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posizione';
$_MODULE['<{oct8ne}prestashop>customerconfig_7075e53a2135d5c3d687fd5a6966e24d'] = 'Header';
$_MODULE['<{oct8ne}prestashop>customerconfig_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'Footer';
$_MODULE['<{oct8ne}prestashop>customerconfig_8ef23b176e99d7facd4f2ad8619a5fd4'] = 'Puoi scegliere dove inserire gli scripts oct8ne: a pie di página o nella testata';
$_MODULE['<{oct8ne}prestashop>customerconfig_3284614a26b9eebe62398c0174743691'] = 'Tipo di immagine';
$_MODULE['<{oct8ne}prestashop>customerconfig_0663eabe90a1e1578e1a090d82f6d89d'] = 'Standard';
$_MODULE['<{oct8ne}prestashop>customerconfig_a5cd0f7fdebcf2afe5c34be8366eb329'] = 'Tipo 1';
$_MODULE['<{oct8ne}prestashop>customerconfig_2141d9976decee64d296a8c3146ab839'] = 'Tipo 1 inserisce l\'ID del prodotto davanti all\'ID dell\'immagine. Utile in casi specifici. Attenzione, modifica questa opzione solo se necessario';
$_MODULE['<{oct8ne}prestashop>customerconfig_c9cc8cce247e49bae79f15173ce97354'] = 'Salvare';
$_MODULE['<{oct8ne}prestashop>customerconfig_b0cc842d01c1807510e37fe22f4d2d67'] = 'Motore di ricerca - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig_7bfa30721c5e726ff17e3f972237a82c'] = 'Motore';
$_MODULE['<{oct8ne}prestashop>customerconfig_935565d6f7077f17422708654b138b47'] = 'Motore di ricerca da utilizzare';
$_MODULE['<{oct8ne}prestashop>customerconfig7_b0d07cb35250063972daeb65e388ee3d'] = 'Configurazione basica - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig7_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posizione';
$_MODULE['<{oct8ne}prestashop>customerconfig7_7075e53a2135d5c3d687fd5a6966e24d'] = 'Header';
$_MODULE['<{oct8ne}prestashop>customerconfig7_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'Footer';
$_MODULE['<{oct8ne}prestashop>customerconfig7_8ef23b176e99d7facd4f2ad8619a5fd4'] = 'Puoi scegliere dove inserire gli scripts oct8ne: a pie di página o nella testata';
$_MODULE['<{oct8ne}prestashop>customerconfig7_3284614a26b9eebe62398c0174743691'] = 'Tipo di immagine';
$_MODULE['<{oct8ne}prestashop>customerconfig7_0663eabe90a1e1578e1a090d82f6d89d'] = 'Standard';
$_MODULE['<{oct8ne}prestashop>customerconfig7_a5cd0f7fdebcf2afe5c34be8366eb329'] = 'Tipo 1';
$_MODULE['<{oct8ne}prestashop>customerconfig7_2141d9976decee64d296a8c3146ab839'] = 'Tipo 1 inserisce l\'ID del prodotto davanti all\'ID dell\'immagine. Utile in casi specifici. Attenzione, modifica questa opzione solo se necessario';
$_MODULE['<{oct8ne}prestashop>customerconfig7_c9cc8cce247e49bae79f15173ce97354'] = 'Salvare';
$_MODULE['<{oct8ne}prestashop>customerconfig7_b0cc842d01c1807510e37fe22f4d2d67'] = 'Motore di ricerca - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig7_7bfa30721c5e726ff17e3f972237a82c'] = 'Motore';
$_MODULE['<{oct8ne}prestashop>customerconfig7_935565d6f7077f17422708654b138b47'] = 'Motore di ricerca da utilizzare';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_af1b98adf7f686b84cd0b443e022b7a0'] = 'Categories';

==> oct8ne-v.1.3.0.zip: oct8ne/translations/it.php <==
<?php

global $_MODULE;
$_MODULE = [];
$_MODULE['<{oct8ne}prestashop>oct8ne_bc741b828f1fc35a6f10c870d6056343'] = 'Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_8ff7439dd2ee3184597be0c738ad566a'] = 'Connettore del modulo Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_a9390206b02d5d06ee405aa6b4d7b232'] = 'Tutti i dati verranno cancellati. Desidera continuare?';
$_MODULE['<{oct8ne}prestashop>oct8ne_004b04925fa8a42d0d28c3862c6947bd'] = 'Identificazione errata. Per favore, verifica le tue credenziali di accesso.';
$_MODULE['<{oct8ne}prestashop>oct8ne_5f2faa4c7bc8b0d9862218f744a1aee3'] = 'Configurazione di Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{oct8ne}prestashop>oct8ne_3d236caa22b35b852d3d9f402ecd361d'] = 'La tua email...';
$_MODULE['<{oct8ne}prestashop>oct8ne_dc647eb65e6711e155375218212b3964'] = 'Password';
$_MODULE['<{oct8ne}prestashop>oct8ne_45e37dc42e288221084fc298cd93c8bb'] = 'La tua password...';
$_MODULE['<{oct8ne}prestashop>oct8ne_98045f7a4e566c2167bac30218c338ac'] = 'Dovrai compilare i campi inserendo i dati dell\'account del pannello di amministrazione di Oct8ne. Se ancora non hai un account di Oct8ne puoi crearlo';
$_MODULE['<{oct8ne}prestashop>oct8ne_6c92285fa6d3e827b198d120ea3ac674'] = 'qui';
$_MODULE['<{oct8ne}prestashop>oct8ne_99dea78007133396a7b8ed70578ac6ae'] = 'Iniziare sessione';
$_MODULE['<{oct8ne}prestashop>oct8ne_87e9c089875dbf587734df396ce7423a'] = 'Base di Prestashop';
$_MODULE['<{oct8ne}prestashop>oct8ne_afaa5ee5fcca30cc8ab8b7b8096d76b8'] = 'Doofinder';
$_MODULE['<{oct8ne}prestashop>oct8ne_ede9e64250ae298e24874dfe3c23c567'] = 'Motore di ricerca di Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_14e69b495b4ad97a1c4a468d99169b21'] = 'Motore';
$_MODULE['<{oct8ne}prestashop>oct8ne_daa6b483e9f6ca081ec7e0b4a352f9e9'] = 'Salvare';
$_MODULE['<{oct8ne}prestashop>oct8ne_d2cb1b13319e5118823778f3e4505f41'] = 'Informazione di Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_8d1bd3e5756e3454644c531701ff73e0'] = 'Usuario Attivo';
$_MODULE['<{oct8ne}prestashop>oct8ne_0323de4f66a1700e2173e9bcdce02715'] = 'Chiudere sessione';
$_MODULE['<{oct8ne}prestashop>oct8ne_3168ca6855e90fdc6ef9a9022b747df3'] = 'Opzioni';
$_MODULE['<{oct8ne}prestashop>oct8ne_031cf59f5628f2828e2433d82aa26c7a'] = 'Puoi scegliere dove caricare gli script di Oct8ne: Nel footer o nel header della pagina';
$_MODULE['<{oct8ne}prestashop>oct8ne_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posizione';
$_MODULE['<{oct8ne}prestashop>oct8ne_1c8d7e5020585439fe9972e6288b3687'] = 'Tipo di Immagini';
$_MODULE['<{oct8ne}prestashop>oct8ne_a743c9120ecd8b14ccf16ed8d12a68d9'] = 'Tipo 1 inserisce l\'id del prodotto davanti all\'id dell\'immagine. Utile in casi specifici. Attenzione, modifica questa opzione solo se necessario';
$_MODULE['<{oct8ne}prestashop>oct8ne_c9cc8cce247e49bae79f15173ce97354'] = 'Salvare';
$_MODULE['<{oct8ne}prestashop>customerconfig_b0d07cb35250063972daeb65e388ee3d'] = 'Configurazione basica - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posizione';
$_MODULE['<{oct8ne}prestashop>customerconfig_7075e53a2135d5c3d687fd5a6966e24d'] = 'Header';
$_MODULE['<{oct8ne}prestashop>customerconfig_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'Footer';
$_MODULE['<{oct8ne}prestashop>customerconfig_8ef23b176e99d7facd4f2ad8619a5fd4'] = 'Puoi scegliere dove inserire gli scripts oct8ne: a pie di página o nella testata';
$_MODULE['<{oct8ne}prestashop>customerconfig_3284614a26b9eebe62398c0174743691'] = 'Tipo di immagine';
$_MODULE['<{oct8ne}prestashop>customerconfig_0663eabe90a1e1578e1a090d82f6d89d'] = 'Standard';
$_MODULE['<{oct8ne}prestashop>customerconfig_a5cd0f7fdebcf2afe5c34be8366eb329'] = 'Tipo 1';
$_MODULE['<{oct8ne}prestashop>customerconfig_2141d9976decee64d296a8c3146ab839'] = 'Tipo 1 inserisce l\'ID del prodotto davanti all\'ID dell\'immagine. Utile in casi specifici. Attenzione, modifica questa opzione solo se necessario';
$_MODULE['<{oct8ne}prestashop>customerconfig_c9cc8cce247e49bae79f15173ce97354'] = 'Salvare';
$_MODULE['<{oct8ne}prestashop>customerconfig_b0cc842d01c1807510e37fe22f4d2d67'] = 'Motore di ricerca - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig_7bfa30721c5e726ff17e3f972237a82c'] = 'Motore';
$_MODULE['<{oct8ne}prestashop>customerconfig_935565d6f7077f17422708654b138b47'] = 'Motore di ricerca da utilizzare';
$_MODULE['<{oct8ne}prestashop>customerconfig7_b0d07cb35250063972daeb65e388ee3d'] = 'Configurazione basica - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig7_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posizione';
$_MODULE['<{oct8ne}prestashop>customerconfig7_7075e53a2135d5c3d687fd5a6966e24d'] = 'Header';
$_MODULE['<{oct8ne}prestashop>customerconfig7_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'Footer';
$_MODULE['<{oct8ne}prestashop>customerconfig7_8ef23b176e99d7facd4f2ad8619a5fd4'] = 'Puoi scegliere dove inserire gli scripts oct8ne: a pie di página o nella testata';
$_MODULE['<{oct8ne}prestashop>customerconfig7_3284614a26b9eebe62398c0174743691'] = 'Tipo di immagine';
$_MODULE['<{oct8ne}prestashop>customerconfig7_0663eabe90a1e1578e1a090d82f6d89d'] = 'Standard';
$_MODULE['<{oct8ne}prestashop>customerconfig7_a5cd0f7fdebcf2afe5c34be8366eb329'] = 'Tipo 1';
$_MODULE['<{oct8ne}prestashop>customerconfig7_2141d9976decee64d296a8c3146ab839'] = 'Tipo 1 inserisce l\'ID del prodotto davanti all\'ID dell\'immagine. Utile in casi specifici. Attenzione, modifica questa opzione solo se necessario';
$_MODULE['<{oct8ne}prestashop>customerconfig7_c9cc8cce247e49bae79f15173ce97354'] = 'Salvare';
$_MODULE['<{oct8ne}prestashop>customerconfig7_b0cc842d01c1807510e37fe22f4d2d67'] = 'Motore di ricerca - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig7_7bfa30721c5e726ff17e3f972237a82c'] = 'Motore';
$_MODULE['<{oct8ne}prestashop>customerconfig7_935565d6f7077f17422708654b138b47'] = 'Motore di ricerca da utilizzare';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_af1b98adf7f686b84cd0b443e022b7a0'] = 'Categories';

$_MODULE['<{oct8ne}prestashop>update_notification_bd8334f553a15234208a32961e69a032'] = 'Nuova versione disponibile!';
$_MODULE['<{oct8ne}prestashop>update_notification_552803cb1363989c9339a7d3a04a520e'] = 'Stai utilizzando la versione';
$_MODULE['<{oct8ne}prestashop>update_notification_d91d8304919741e24744d07b8b4226f7'] = 'Versione';
$_MODULE['<{oct8ne}prestashop>update_notification_4901f40398019e07246543b50c021c35'] = 'è disponibile.';
$_MODULE['<{oct8ne}prestashop>update_notification_8e35359a0df470e806c99c8509c693a2'] = 'Scarica v';
